==> haskell-reinterpret-cast-0.1.0-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-reinterpret-cast.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: reinterpret-cast
version: 0.1.0
id: reinterpret-cast-0.1.0-LUYxmYG7FmrHtnPy1Uq8C5
key: reinterpret-cast-0.1.0-LUYxmYG7FmrHtnPy1Uq8C5
license: MIT
copyright: 2014 Niklas Hambüchen <mail@nh2.me>
maintainer: Niklas Hambüchen <mail@nh2.me>
author: Niklas Hambüchen <mail@nh2.me>
stability: experimental
homepage: https://github.com/nh2/reinterpret-cast
synopsis: Memory reinterpretation casts for Float/Double and Word32/Word64
description:
    Memory reinterpretation casts for Float\/Double and Word32\/Word64.
    .
    The implementations in the @.Internal@ package are different ways to tackle
    the problem; the @array@ method (current default) is about 5 times faster
    than the @FFI@ method.
category: Data
abi: fc10bc22894b8837875181dc232911f4
exposed: True
exposed-modules:
    Data.ReinterpretCast Data.ReinterpretCast.Internal.ImplArray
    Data.ReinterpretCast.Internal.ImplFFI
import-dirs: /usr/lib/ghc-8.4.3/site-local/reinterpret-cast-0.1.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/reinterpret-cast-0.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/reinterpret-cast-0.1.0
hs-libraries: HSreinterpret-cast-0.1.0-LUYxmYG7FmrHtnPy1Uq8C5
depends:
    base-4.11.1.0 array-0.5.2.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
haddock-interfaces: /usr/share/doc/haskell-reinterpret-cast/html/reinterpret-cast.haddock
haddock-html: /usr/share/doc/haskell-reinterpret-cast/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-reinterpret-cast-0.1.0-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-reinterpret-cast.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: reinterpret-cast
version: 0.1.0
id: reinterpret-cast-0.1.0-9Rkr8qso0KhJ555hZFw0yJ
key: reinterpret-cast-0.1.0-9Rkr8qso0KhJ555hZFw0yJ
license: MIT
copyright: 2014 Niklas Hambüchen <mail@nh2.me>
maintainer: Niklas Hambüchen <mail@nh2.me>
author: Niklas Hambüchen <mail@nh2.me>
stability: experimental
homepage: https://github.com/nh2/reinterpret-cast
synopsis: Memory reinterpretation casts for Float/Double and Word32/Word64
description:
    Memory reinterpretation casts for Float\/Double and Word32\/Word64.
    .
    The implementations in the @.Internal@ package are different ways to tackle
    the problem; the @array@ method (current default) is about 5 times faster
    than the @FFI@ method.
category: Data
abi: 62b0900b59a86aa9a78db4a71bd7281e
exposed: True
exposed-modules:
    Data.ReinterpretCast Data.ReinterpretCast.Internal.ImplArray
    Data.ReinterpretCast.Internal.ImplFFI
import-dirs: /usr/lib/ghc-8.4.3/site-local/reinterpret-cast-0.1.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/reinterpret-cast-0.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/reinterpret-cast-0.1.0
hs-libraries: HSreinterpret-cast-0.1.0-9Rkr8qso0KhJ555hZFw0yJ
depends:
    base-4.11.1.0 array-0.5.2.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
haddock-interfaces: /usr/share/doc/haskell-reinterpret-cast/html/reinterpret-cast.haddock
haddock-html: /usr/share/doc/haskell-reinterpret-cast/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
